- x
(Required) Microbial community data. This must be in the form of a phyloseq object and must contain, at a minimum, an OTU abundance table and a phylogeny.
- grouping
(Required) A vector specifying which samples belong to which habitat type.
- core_fraction
The fraction of samples that a microbial taxon must be found in to be considered part of the 'core' microbiome. This variable is only used when selection = 'basic' and is ignored when selection = 'shade'. The default value is 0.5.
- ab_threshold1
The threshold for mean relative abundance across all samples. This variable is only used when selection = 'basic' and is ignored when selection = 'shade'. The default value is 0.
- ab_threshold2
The threshold for maximum relative abundance in any sample. This variable is only used when selection = 'basic' and is ignored when selection = 'shade'. The default value is 0.
- ab_threshold3
The threshold for minimum relative abundance across all samples. This variable is only used when selection = 'basic' and is ignored when selection = 'shade'. The default value is 0.
- selection
Whether to use thresholds ('basic') or the Shade and Stopnisek method ('shade') to define the core community. The default is 'basic'.
- max_tax
The maximum number of branches to add sequentially, as a percentage of the total branches when using the Shade and Stopnisek method. This variable is only used when selection = 'shade' and is ignored when selection = 'basic'.
- increase_cutoff
The threshold for the percent increase in beta diversity used to identify the taxon at which point adding more taxa yields diminishing returns in explanatory power. This variable is only used when selection = 'shade' and is ignored when selection = 'basic'.
- ordered_groups
When provided, specifies the order in which different habitats should be plotted. This order is matched to the color order specified in fill_color (see below).
- show_percentage
If TRUE the Venn diagram is shown as percentages of the total branch length in each compartment. If FALSE the Venn diagram is shown as absolute branch lengths.
- decimal
The number of decimal points to report in the Venn diagram compartments (either for percentages or absolute branch lengths).
- fill_color
A vector specifying the colors to use for each of the different habitats in the Venn diagram. The default is to use the six colors of the rainbow, followed by black.
- fill_alpha
The transparency of the fill colors in the Venn diagram.
- stroke_color
The color of the outlines in the Venn diagram.
- stroke_alpha
The transparency of the outlines in the Venn diagram.
- stroke_size
The width of the outlines in the Venn diagram.
- stroke_linetype
The style of the outlines in the Venn diagram.
- set_name_color
The color of the font used to label each habitat.
- set_name_size
The size of the font used to label each habitat
- text_color
The color of the font used to report the value in each compartment of the Venn diagram
- text_size
The size of the font used to report the value in each compartment of the Venn diagram